# Neural Networks

::: warpconvnet.nn

## Modules

### Activations

::: warpconvnet.nn.modules.activations

### Attention

::: warpconvnet.nn.modules.attention

### Base module

::: warpconvnet.nn.modules.base_module

### Factor grid

::: warpconvnet.nn.modules.factor_grid

### Grid convolution

::: warpconvnet.nn.modules.grid_conv

### MLP

::: warpconvnet.nn.modules.mlp

### Normalizations

::: warpconvnet.nn.modules.normalizations

### Point convolution

::: warpconvnet.nn.modules.point_conv

### Point pooling

::: warpconvnet.nn.modules.point_pool

### Prune

::: warpconvnet.nn.modules.prune

### Sequential

::: warpconvnet.nn.modules.sequential

### Sparse convolution

::: warpconvnet.nn.modules.sparse_conv

### Sparse depthwise convolution

::: warpconvnet.nn.modules.sparse_conv_depth

### Sparse pooling

::: warpconvnet.nn.modules.sparse_pool

### Transforms

::: warpconvnet.nn.modules.transforms
